@@ -34,18 +34,19 @@
 #include <KDebug>
 #include <KApplication>
 
-MenuWidget::MenuWidget(QGraphicsView *view, QMenu *menu) :
+MenuWidget::MenuWidget(QGraphicsView *view) :
     QGraphicsWidget(),
     m_mouseTimer(new QTimer(this)),
+    m_actionTimer(new QTimer(this)),
     m_view(view),
     m_layout(new QGraphicsLinearLayout(this)),
     m_currentButton(0),
-    m_aMenuIsVisible(false),
     m_contentBottomMargin(0),
-    m_menu(menu)
+    m_visibleMenu(0),
+    m_menu(0)
 {
+    connect(m_actionTimer, SIGNAL(timeout()), SLOT(slotUpdateActions()));
     connect(m_mouseTimer, SIGNAL(timeout()), SLOT(slotCheckActiveItem()));
-    m_menu->installEventFilter(this);
 }
 
 MenuWidget::~MenuWidget()
@@ -57,24 +58,36 @@ MenuWidget::~MenuWidget()
     }
 }
 
+void MenuWidget::setMenu(QMenu *menu)
+{
+    if (m_menu) {
+        disconnect(m_menu, SIGNAL(destroyed()), this, SLOT(slotMenuDestroyed()));
+        m_menu->removeEventFilter(this);
+    }
+    if (menu) {
+        m_menu = menu;
+        connect(m_menu, SIGNAL(destroyed()), SLOT(slotMenuDestroyed()), Qt::UniqueConnection);
+        m_menu->installEventFilter(this);
+        slotUpdateActions();
+    }
+}
+
 void MenuWidget::initLayout()
 {
     MenuButton* button = 0;
-    foreach( QAction* action, m_menu->actions() )
-    {
-        QMenu *menu = action->menu();
-        action->setShortcut(QKeySequence());
-        if( action->isSeparator() || !menu )
-            continue;
 
-        //Create a new button, we do not set menu here as it may have changed on showMenu()
-        button = new MenuButton(this);
-        button->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
-        button->setAction(action);
-        button->setText(action->text()); // mnemonic missing otherwise :-(
-        connect(button, SIGNAL(clicked()), SLOT(slotButtonClicked()));
-        m_layout->addItem(button);
-        m_buttons << button;
+    if (!m_menu) {
+        return;
+    }
+
+    foreach (QAction* action, m_menu->actions())
+    {
+        button = createButton(action);
+        if (button) {
+            m_layout->addItem(button);
+            button->setMenu(action->menu());
+            m_buttons << button;
+        }
     }
 
     //Assume all buttons have same margins
@@ -83,36 +96,6 @@ void MenuWidget::initLayout()
     }
 }
 
-void MenuWidget::updateLayout(QMenu *menu)
-{
-    bool mouseTimer = false;
-
-    m_menu = 0;
-    m_currentButton = 0;
-
-    if (m_mouseTimer->isActive()) {
-       m_mouseTimer->stop();
-       mouseTimer = true;
-    }
-
-    //Clear layout
-    foreach (MenuButton *button, m_buttons) {
-        disconnect(button, SIGNAL(clicked()), this, SLOT(slotButtonClicked()));
-        m_layout->removeItem(button);
-        button->hide();
-        m_buttons.removeOne(button);
-        button->deleteLater();
-    }
-
-    m_menu = menu;
-    m_menu->installEventFilter(this);
-    initLayout();
-    m_layout->invalidate();
-    if (mouseTimer) {
-        m_mouseTimer->start();
-    }
-}
-
 bool MenuWidget::eventFilter(QObject* object, QEvent* event)
 {
     bool filtered;
@@ -128,11 +111,10 @@ bool MenuWidget::menuEventFilter(QEvent* event)
 {
     switch (event->type()) {
     case QEvent::ActionAdded:
-        //If all actions added, update buttons actions
-        //We know number of actions can't change as our menuimporter track LayoutUpdated() dbus signal
-        if (m_menu->actions().length() == m_buttons.length()) {
-            updateActions();
-        }
+    case QEvent::ActionRemoved:
+    case QEvent::ActionChanged:
+        // Try to limit layout updates
+        m_actionTimer->start(500);
         break;
     default:
         break;
@@ -169,6 +151,11 @@ bool MenuWidget::subMenuEventFilter(QObject* object, QEvent* event)
     return false;
 }
 
+void MenuWidget::slotMenuDestroyed()
+{
+    m_menu = 0;
+}
+
 void MenuWidget::slotCheckActiveItem()
 {
     MenuButton* buttonBelow = 0;
@@ -184,17 +171,10 @@ void MenuWidget::slotCheckActiveItem()
     if (buttonBelow != m_currentButton) {
         if (m_currentButton) {
             m_currentButton->nativeWidget()->setDown(false);
-            m_currentButton->setHovered( false );
-            QAction *action = m_currentButton->action();
-            if (action) {
-                QMenu *menu = action->menu();
-                disconnect(menu, SIGNAL(aboutToHide()), this, SLOT(slotMenuAboutToHide()));
-                menu->hide();
-                m_aMenuIsVisible = false;
-            }
+            m_currentButton->setHovered(false);
             m_currentButton = buttonBelow;
             m_currentButton->nativeWidget()->setDown(true);
-            showMenu();
+            m_visibleMenu = showMenu();
         }
     }
 }
@@ -202,11 +182,11 @@ void MenuWidget::slotCheckActiveItem()
 void MenuWidget::slotMenuAboutToHide()
 {
     if (m_currentButton) {
-        m_currentButton->setDown( false );
+        m_currentButton->setDown(false);
     }
     if (m_mouseTimer->isActive())
         m_mouseTimer->stop();
-    m_aMenuIsVisible = false;
+    m_visibleMenu = 0;
     emit aboutToHide();
 }
 
@@ -215,21 +195,48 @@ void MenuWidget::slotButtonClicked()
     m_currentButton = qobject_cast<MenuButton*>(sender());
 
     m_currentButton->nativeWidget()->setDown(true);
-    showMenu();
+    m_visibleMenu = showMenu();
     // Start auto navigation after click
     if (!m_mouseTimer->isActive())
         m_mouseTimer->start(100);
 }
 
+void MenuWidget::slotUpdateActions()
+{
+    if (m_visibleMenu) {
+        return; // Later
+    }
+
+    m_actionTimer->stop();
+    foreach (MenuButton *button, m_buttons) {
+        disconnect(button, SIGNAL(clicked()), this, SLOT(slotButtonClicked()));
+        m_layout->removeItem(button);
+        button->hide();
+        m_buttons.removeOne(button);
+        delete button;
+    }
+    initLayout();
+    // Menu may be empty on application startup
+    // slotUpdateActions will be called later by eventFilter()
+    if (m_menu && m_menu->actions().length()) {
+        emit needResize();
+    }
+}
+
 void MenuWidget::setActiveAction(QAction *action)
 {
+    if (!m_menu) {
+        return;
+    }
+
     m_currentButton = m_buttons.first();
 
     if (action) {
-        QAction *menuAction;
+        QMenu *menu;
+        int i = 0;
         foreach (MenuButton *button, m_buttons) {
-            menuAction = button->action();
-            if (menuAction && menuAction == action) {
+            menu = m_menu->actions()[i]->menu();
+            if (menu && menu == action->menu()) {
                 m_currentButton = button;
                 break;
             }
@@ -240,25 +247,60 @@ void MenuWidget::setActiveAction(QAction *action)
 
 void MenuWidget::hide()
 {
-    if (m_mouseTimer->isActive())
+    if (m_mouseTimer->isActive()) {
         m_mouseTimer->stop();
+    }
     QGraphicsWidget::hide();
 }
 
-bool MenuWidget::showMenu()
+MenuButton* MenuWidget::createButton(QAction *action)
 {
-    QAction *action = m_currentButton->action();
-    if (action) {
-        QMenu *menu = action->menu();
+    if( action->isSeparator() || !action->menu() || !action->isVisible()) {
+        return 0;
+    }
+
+    action->setShortcut(QKeySequence());
+    MenuButton *button = new MenuButton(this);
+    button->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
+    button->setText(action->text());
+    connect(button, SIGNAL(clicked()), SLOT(slotButtonClicked()));
+    return button;
+}
+
+QMenu* MenuWidget::showMenu()
+{
+    QMenu *menu = 0;
+
+    if (m_visibleMenu) {
+        disconnect(m_visibleMenu, SIGNAL(aboutToHide()), this, SLOT(slotMenuAboutToHide()));
+        m_visibleMenu->hide();
+    }
+
+    if (m_currentButton && m_menu) {
+        menu = m_currentButton->menu();
+    }
+
+    // Last chance to get menu
+    // Some applications like Firefox have empties menus on layout updates
+    // They should populate this menu later but in fact, they use another object
+    // So, we check here directly the button name, may fail with menubar with buttons with same name (test apps)
+    if (menu && menu->actions().length() == 0) {
+        foreach (QAction *action, m_menu->actions()) {
+            if (action->text() == m_currentButton->text()) {
+                menu = action->menu();
+                break;
+            }
+        }
+    }
+
+    if (menu) {
         QPoint globalPos = m_view->mapToGlobal(QPoint(0,0));
         QPointF parentPos =  m_currentButton->mapFromParent(QPoint(0,0));
         QRect screen = KApplication::desktop()->screenGeometry();
         int x = globalPos.x() - parentPos.x();
         int y = globalPos.y() + m_currentButton->size().height() - parentPos.y();
 
-        m_currentButton->setAction(action);
         menu->popup(QPoint(x, y));
-        m_aMenuIsVisible = true;
 
         // Fix offscreen menu
         if (menu->size().height() + y > screen.height() + screen.y()) {
@@ -273,13 +315,16 @@ bool MenuWidget::showMenu()
         connect(menu, SIGNAL(aboutToHide()), this, SLOT(slotMenuAboutToHide()));
 
         installEventFilterForAll(menu, this);
-        return true;
     }
-    return false;
+    return menu;
 }
 
 void MenuWidget::showLeftRightMenu(bool next)
 {
+    if (!m_currentButton) {
+        return;
+    }
+
     int index = m_buttons.indexOf(m_currentButton);
     if (index == -1) {
         kWarning() << "Couldn't find button!";
@@ -291,33 +336,18 @@ void MenuWidget::showLeftRightMenu(bool next)
         index = (index == 0 ? m_buttons.count() : index) - 1;
     }
 
-    QAction *action = m_currentButton->action();
-
-    if (action) {
-        QMenu *menu = action->menu();
-        disconnect(menu, SIGNAL(aboutToHide()), this, SLOT(slotMenuAboutToHide()));
-        m_aMenuIsVisible = false;
-        menu->hide();
-    }
-
     m_currentButton->setDown(false);
     m_currentButton = m_buttons.at(index);
     m_currentButton->nativeWidget()->setDown(true);
-    showMenu();
-}
-
-void MenuWidget::updateActions()
-{
-    uint i = 0;
-    foreach(QAction *action, m_menu->actions()) {
-        m_buttons[i]->setAction(action);
-        m_buttons[i]->setText(action->text()); // mnemonic missing otherwise :-(
-        ++i;
-    }
+    m_visibleMenu = showMenu();
 }
 
 void MenuWidget::installEventFilterForAll(QMenu *menu, QObject *object)
 {
+    if (!menu) {
+        return;
+    }
+
     menu->installEventFilter(this);
 
     foreach (QAction *action, menu->actions()) {
