@@ -38,26 +38,21 @@ class MenuWidget : public QGraphicsWidget
 {
 Q_OBJECT
 public:
-    MenuWidget(QGraphicsView *view = 0, QMenu *menu = 0);
+    MenuWidget(QGraphicsView *view = 0);
     ~MenuWidget();
 
+    /**
+     * Set root menu
+     */
+    void setMenu(QMenu *menu);
     /**
      *  Init layout with root menu
      */
     void initLayout();
     /**
-     * Update layout with menu
+     * True if a menu is visible in menuwidget
      */
-    void updateLayout(QMenu *menu);
-    /**
-     * Return true if layout is valid and populated
-     */
-    bool layoutValid();
-    /**
-     * True if a menu is visible in menubar
-     */
-    bool aMenuIsVisible() { return m_aMenuIsVisible; }
-
+    bool aMenuIsVisible() { return m_visibleMenu; }
     /**
      * Activate action, or first action if null
      */
@@ -80,7 +75,6 @@ protected:
      * Use to get keyboard events
      */
     virtual bool eventFilter(QObject*, QEvent*);
-private Q_SLOTS:
     /**
      * Filter events on main menu
      */
@@ -89,34 +83,44 @@ private Q_SLOTS:
      * Filter events on submenus
      */
     bool subMenuEventFilter(QObject* object, QEvent* event);
+private Q_SLOTS:
+    /**
+     * Clean menu if destroyed
+     */
+    void slotMenuDestroyed();
     /**
      * Check hovered item and active it
      */
     void slotCheckActiveItem();
     /**
-     * a menu is hidding
+     * A menu is hidding
      */
     void slotMenuAboutToHide();
     /**
-     * menubar button clicked
+     * Menubar button clicked
      */
     void slotButtonClicked();
+    /**
+     * Update pending actions
+     */
+    void slotUpdateActions();
 Q_SIGNALS:
+    void needResize();
     void aboutToHide();
 private:
     /**
-     * Show current button menu
-     * return true if menu is shown
+     * Return a button based on action
      */
-    bool showMenu();
+    MenuButton* createButton(QAction *action);
+    /**
+     * Show current button menu
+     * return showed menu
+     */
+    QMenu* showMenu();
     /**
      * Show next menu if next, otherwise previous
      */
     void showLeftRightMenu(bool next);
-    /**
-     * Update buttons actions
-     */
-    void updateActions();
     /**
      * Install event filter for menu and it submenus
      */
@@ -124,12 +128,14 @@ private:
 
     //Follow mouse position
     QTimer *m_mouseTimer;
+    //Update actions
+    QTimer *m_actionTimer;
     QGraphicsView *m_view;
     QGraphicsLinearLayout *m_layout;
     QList<MenuButton*> m_buttons;
     MenuButton *m_currentButton;
-    bool m_aMenuIsVisible;
     qreal m_contentBottomMargin;
+    QMenu *m_visibleMenu;
     QMenu *m_menu;
 };
 
