@@ -35,6 +35,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QtGui/QGraphicsLinearLayout>
 #include <Plasma/FrameSvg>
 #include <Plasma/PushButton>
+#include <Plasma/Theme>
 #include <Plasma/WindowEffects>
 #include <netwm_def.h>
 
@@ -337,7 +338,7 @@ void PresentWindowsEffect::paintWindow(EffectWindow *w, int mask, QRegion region
             m_motionManager.apply(w, data);
             QRect rect = m_motionManager.transformedGeometry(w).toRect();
 
-            if (m_activated && winData->highlight > 0.0) {
+            if (m_activated && winData->highlight > 0.0 && !m_motionManager.areWindowsMoving()) {
                 // scale the window (interpolated by the highlight level) to at least 105% or to cover 1/16 of the screen size - yet keep it in screen bounds
                 QRect area = effects->clientArea(FullScreenArea, w);
 
@@ -1961,7 +1962,11 @@ CloseWindowView::CloseWindowView(QWidget* parent)
     scene->addItem(form);
 
     m_frame = new Plasma::FrameSvg(this);
-    m_frame->setImagePath("dialogs/background");
+    if (Plasma::Theme::defaultTheme()->currentThemeHasImage("translucent/dialogs/background")) {
+        m_frame->setImagePath("translucent/dialogs/background");
+    } else {
+        m_frame->setImagePath("dialogs/background");
+    }
     m_frame->setCacheAllRenderedFrames(true);
     m_frame->setEnabledBorders(Plasma::FrameSvg::AllBorders);
     qreal left, top, right, bottom;
@@ -1970,7 +1975,6 @@ CloseWindowView::CloseWindowView(QWidget* parent)
     qreal height = form->size().height() + top + bottom;
     m_frame->resizeFrame(QSizeF(width, height));
     Plasma::WindowEffects::enableBlurBehind(winId(), true, m_frame->mask());
-    Plasma::WindowEffects::overrideShadow(winId(), true);
     form->setPos(left, top);
     scene->setSceneRect(QRectF(QPointF(0, 0), QSizeF(width, height)));
     setScene(scene);
