@@ -85,6 +85,7 @@ RulesWidget::RulesWidget(QWidget* parent)
     SETUP(position, set);
     SETUP(size, set);
     SETUP(desktop, set);
+    SETUP(screen, set);
     SETUP(activity, set);
     SETUP(maximizehoriz, set);
     SETUP(maximizevert, set);
@@ -106,7 +107,6 @@ RulesWidget::RulesWidget(QWidget* parent)
     SETUP(autogroupid, force);
     SETUP(opacityactive, force);
     SETUP(opacityinactive, force);
-    SETUP(tilingoption, force);
     SETUP(shortcut, force);
     // workarounds tab
     SETUP(fsplevel, force);
@@ -118,7 +118,6 @@ RulesWidget::RulesWidget(QWidget* parent)
     SETUP(disableglobalshortcuts, force);
     SETUP(blockcompositing, force);
 
-    connect (title_match, SIGNAL(currentIndexChanged(int)), SLOT(titleMatchChanged()));
     connect (machine_match, SIGNAL(currentIndexChanged(int)), SLOT(machineMatchChanged()));
     connect (shortcut_edit, SIGNAL(clicked()), SLOT(shortcutEditClicked()));
 
@@ -154,6 +153,7 @@ RulesWidget::RulesWidget(QWidget* parent)
 UPDATE_ENABLE_SLOT(position)
 UPDATE_ENABLE_SLOT(size)
 UPDATE_ENABLE_SLOT(desktop)
+UPDATE_ENABLE_SLOT(screen)
 UPDATE_ENABLE_SLOT(activity)
 UPDATE_ENABLE_SLOT(maximizehoriz)
 UPDATE_ENABLE_SLOT(maximizevert)
@@ -175,7 +175,6 @@ UPDATE_ENABLE_SLOT(autogroupfg)
 UPDATE_ENABLE_SLOT(autogroupid)
 UPDATE_ENABLE_SLOT(opacityactive)
 UPDATE_ENABLE_SLOT(opacityinactive)
-UPDATE_ENABLE_SLOT(tilingoption)
 void RulesWidget::updateEnableshortcut()
 {
     shortcut->setEnabled(enable_shortcut->isChecked() && rule_shortcut->currentIndex() != 0);
@@ -311,16 +310,6 @@ QString RulesWidget::comboToActivity(int val) const
     return activity->itemData(val).toString();
 }
 
-int RulesWidget::tilingToCombo(int t) const
-{
-    return qBound(0, t, 1);
-}
-
-int RulesWidget::comboToTiling(int val) const
-{
-    return val; // 0 is tiling, 1 is floating
-}
-
 static int placementToCombo(Placement::Policy placement)
 {
     static const int conv[] = {
@@ -416,6 +405,7 @@ static NET::WindowType comboToType(int val)
 #define CHECKBOX_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, setChecked, setChecked( false ))
 #define LINEEDIT_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, setText, setText( "" ))
 #define COMBOBOX_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, setCurrentIndex, setCurrentIndex( 0 ))
+#define SPINBOX_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, setValue, setValue(0))
 #define CHECKBOX_FORCE_RULE( var, func ) GENERIC_RULE( var, func, Force, force, setChecked, setChecked( false ))
 #define LINEEDIT_FORCE_RULE( var, func ) GENERIC_RULE( var, func, Force, force, setText, setText( "" ))
 #define COMBOBOX_FORCE_RULE( var, func ) GENERIC_RULE( var, func, Force, force, setCurrentIndex, setCurrentIndex( 0 ))
@@ -453,6 +443,7 @@ void RulesWidget::setRules(Rules* rules)
     LINEEDIT_SET_RULE(position, positionToStr);
     LINEEDIT_SET_RULE(size, sizeToStr);
     COMBOBOX_SET_RULE(desktop, desktopToCombo);
+    SPINBOX_SET_RULE(screen, inc);
     COMBOBOX_SET_RULE(activity, activityToCombo);
     CHECKBOX_SET_RULE(maximizehoriz,);
     CHECKBOX_SET_RULE(maximizevert,);
@@ -473,7 +464,6 @@ void RulesWidget::setRules(Rules* rules)
     LINEEDIT_FORCE_RULE(autogroupid,);
     SPINBOX_FORCE_RULE(opacityactive,);
     SPINBOX_FORCE_RULE(opacityinactive,);
-    COMBOBOX_FORCE_RULE(tilingoption, tilingToCombo);
     LINEEDIT_SET_RULE(shortcut,);
     COMBOBOX_FORCE_RULE(fsplevel,);
     COMBOBOX_FORCE_RULE(type, typeToCombo);
@@ -489,6 +479,7 @@ void RulesWidget::setRules(Rules* rules)
 #undef CHECKBOX_SET_RULE
 #undef LINEEDIT_SET_RULE
 #undef COMBOBOX_SET_RULE
+#undef SPINBOX_SET_RULE
 #undef CHECKBOX_FORCE_RULE
 #undef LINEEDIT_FORCE_RULE
 #undef COMBOBOX_FORCE_RULE
@@ -506,6 +497,7 @@ void RulesWidget::setRules(Rules* rules)
 #define CHECKBOX_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, isChecked )
 #define LINEEDIT_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, text )
 #define COMBOBOX_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, currentIndex )
+#define SPINBOX_SET_RULE( var, func ) GENERIC_RULE( var, func, Set, set, value)
 #define CHECKBOX_FORCE_RULE( var, func ) GENERIC_RULE( var, func, Force, force, isChecked )
 #define LINEEDIT_FORCE_RULE( var, func ) GENERIC_RULE( var, func, Force, force, text )
 #define COMBOBOX_FORCE_RULE( var, func ) GENERIC_RULE( var, func, Force, force, currentIndex )
@@ -548,6 +540,7 @@ Rules* RulesWidget::rules() const
     LINEEDIT_SET_RULE(position, strToPosition);
     LINEEDIT_SET_RULE(size, strToSize);
     COMBOBOX_SET_RULE(desktop, comboToDesktop);
+    SPINBOX_SET_RULE(screen, dec);
     COMBOBOX_SET_RULE(activity, comboToActivity);
     CHECKBOX_SET_RULE(maximizehoriz,);
     CHECKBOX_SET_RULE(maximizevert,);
@@ -568,7 +561,6 @@ Rules* RulesWidget::rules() const
     LINEEDIT_FORCE_RULE(autogroupid,);
     SPINBOX_FORCE_RULE(opacityactive,);
     SPINBOX_FORCE_RULE(opacityinactive,);
-    COMBOBOX_FORCE_RULE(tilingoption, comboToTiling);
     LINEEDIT_SET_RULE(shortcut,);
     COMBOBOX_FORCE_RULE(fsplevel,);
     COMBOBOX_FORCE_RULE(type, comboToType);
@@ -585,6 +577,7 @@ Rules* RulesWidget::rules() const
 #undef CHECKBOX_SET_RULE
 #undef LINEEDIT_SET_RULE
 #undef COMBOBOX_SET_RULE
+#undef SPINBOX_SET_RULE
 #undef CHECKBOX_FORCE_RULE
 #undef LINEEDIT_FORCE_RULE
 #undef COMBOBOX_FORCE_RULE
@@ -688,7 +681,6 @@ void RulesWidget::prefillUnusedValues(const KWindowInfo& info)
     //LINEEDIT_PREFILL( autogroupid, );
     SPINBOX_PREFILL(opacityactive, , 100 /*get the actual opacity somehow*/);
     SPINBOX_PREFILL(opacityinactive, , 100 /*get the actual opacity somehow*/);
-    COMBOBOX_PREFILL(tilingoption, tilingToCombo, 0);
     //LINEEDIT_PREFILL( shortcut, );
     //COMBOBOX_PREFILL( fsplevel, );
     COMBOBOX_PREFILL(type, typeToCombo, info.windowType(SUPPORTED_MANAGED_WINDOW_TYPES_MASK));
