@@ -75,12 +75,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QGraphicsScene>
 #include <QGraphicsView>
-#include <QDesktopWidget>
 
 #include "client.h"
 #include "deleted.h"
 #include "effects.h"
-#include "lanczosfilter.h"
 #include "overlaywindow.h"
 #include "shadow.h"
 
@@ -93,20 +91,16 @@ namespace KWin
 // Scene
 //****************************************
 
-Scene* scene = 0;
-
 Scene::Scene(Workspace* ws)
     : QObject(ws)
     , wspace(ws)
-    , has_waitSync(false)
-    , m_overlayWindow(new OverlayWindow())
 {
     last_time.invalidate(); // Initialize the timer
+    connect(Workspace::self(), SIGNAL(deletedRemoved(KWin::Deleted*)), SLOT(windowDeleted(KWin::Deleted*)));
 }
 
 Scene::~Scene()
 {
-    delete m_overlayWindow;
 }
 
 // returns mask and possibly modified region
@@ -264,8 +258,22 @@ void Scene::paintSimpleScreen(int orig_mask, QRegion region)
 
         // Clip out the decoration for opaque windows; the decoration is drawn in the second pass
         if (w->isOpaque()) {
+            Client *c = NULL;
+            if (topw->isClient()) {
+                c = static_cast<Client*>(topw);
+            }
             // the window is fully opaque
-            data.clip = w->clientShape().translated(w->x(), w->y());
+            if (c && c->decorationHasAlpha()) {
+                // decoration uses alpha channel, so we may not exclude it in clipping
+                data.clip = w->clientShape().translated(w->x(), w->y());
+            } else {
+                // decoration is fully opaque
+                if (c && c->isShade()) {
+                    data.clip = QRegion();
+                } else {
+                    data.clip = w->shape().translated(w->x(), w->y());
+                }
+            }
         } else if (topw->hasAlpha() && topw->opacity() == 1.0) {
             // the window is partially opaque
             data.clip = (w->clientShape() & topw->opaqueRegion().translated(topw->clientPos())).translated(w->x(), w->y());
@@ -360,7 +368,7 @@ void Scene::paintWindow(Window* w, int mask, QRegion region, WindowQuadList quad
         }
         EffectWindowImpl *thumb = it.value().data();
         WindowPaintData thumbData(thumb);
-        thumbData.opacity = data.opacity;
+        thumbData.setOpacity(data.opacity());
 
         const QRect visualThumbRect(thumb->expandedGeometry());
 
@@ -369,8 +377,8 @@ void Scene::paintWindow(Window* w, int mask, QRegion region, WindowQuadList quad
         if (size.width() > visualThumbRect.width() || size.height() > visualThumbRect.height()) {
             size = QSizeF(visualThumbRect.size());
         }
-        thumbData.xScale = size.width() / static_cast<qreal>(visualThumbRect.width());
-        thumbData.yScale = size.height() / static_cast<qreal>(visualThumbRect.height());
+        thumbData.setXScale(size.width() / static_cast<qreal>(visualThumbRect.width()));
+        thumbData.setYScale(size.height() / static_cast<qreal>(visualThumbRect.height()));
         // it can happen in the init/closing phase of the tabbox
         // that the corresponding QGraphicsScene is not available
         if (item->scene() == 0) {
@@ -406,15 +414,17 @@ void Scene::paintWindow(Window* w, int mask, QRegion region, WindowQuadList quad
             continue;
         }
         const QPoint point = viewPos + declview->mapFromScene(item->scenePos());
-        const qreal x = point.x() + w->x() + (item->width() - size.width())/2;
-        const qreal y = point.y() + w->y() + (item->height() - size.height()) / 2;
-        thumbData.xTranslate = x - thumb->x();
+        qreal x = point.x() + w->x() + (item->width() - size.width())/2;
+        qreal y = point.y() + w->y() + (item->height() - size.height()) / 2;
+        x -= thumb->x();
+        y -= thumb->y();
         // compensate shadow topleft padding
-        thumbData.xTranslate += (thumb->x()-visualThumbRect.x())*thumbData.xScale;
-        thumbData.yTranslate = y - thumb->y();
-        thumbData.yTranslate += (thumb->y()-visualThumbRect.y())*thumbData.yScale;
+        x += (thumb->x()-visualThumbRect.x())*thumbData.xScale();
+        y += (thumb->y()-visualThumbRect.y())*thumbData.yScale();
+        thumbData.setXTranslation(x);
+        thumbData.setYTranslation(y);
         int thumbMask = PAINT_WINDOW_TRANSFORMED | PAINT_WINDOW_LANCZOS;
-        if (thumbData.opacity == 1.0) {
+        if (thumbData.opacity() == 1.0) {
             thumbMask |= PAINT_WINDOW_OPAQUE;
         } else {
             thumbMask |= PAINT_WINDOW_TRANSLUCENT;
@@ -442,26 +452,17 @@ void Scene::finalPaintWindow(EffectWindowImpl* w, int mask, QRegion region, Wind
 // will be eventually called from drawWindow()
 void Scene::finalDrawWindow(EffectWindowImpl* w, int mask, QRegion region, WindowPaintData& data)
 {
-    if (mask & PAINT_WINDOW_LANCZOS) {
-        if (lanczos_filter.isNull()) {
-            lanczos_filter = new LanczosFilter(this);
-            // recreate the lanczos filter when the screen gets resized
-            connect(QApplication::desktop(), SIGNAL(screenCountChanged(int)), lanczos_filter.data(), SLOT(deleteLater()));
-            connect(QApplication::desktop(), SIGNAL(resized(int)), lanczos_filter.data(), SLOT(deleteLater()));
-        }
-        lanczos_filter.data()->performPaint(w, mask, region, data);
-    } else
-        w->sceneWindow()->performPaint(mask, region, data);
+    w->sceneWindow()->performPaint(mask, region, data);
 }
 
-OverlayWindow* Scene::overlayWindow()
+bool Scene::waitSyncAvailable() const
 {
-    return m_overlayWindow;
+    return false;
 }
 
 void Scene::screenGeometryChanged(const QSize &size)
 {
-    m_overlayWindow->resize(size);
+    overlayWindow()->resize(size);
 }
 
 //****************************************
